Stan Math Library: stan/math/fwd/scal/fun/floor.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

floor.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_FUN_FLOOR_HPP
2 #define STAN_MATH_FWD_SCAL_FUN_FLOOR_HPP
3
4 #include <stan/math/fwd/core.hpp>
5 #include <cmath>
6
7 namespace stan {
8 namespace math {
9
10 template <typename T>
11 inline fvar<T> floor(const fvar<T>& x) {
12 using std::floor;
13 return fvar<T>(floor(x.val_), 0);
14 }
15
16 }
17 }
18 #endif
core.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::floor
var floor(const var &a)
Return the floor of the specified variable (cmath).
Definition: floor.hpp:60
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
stan::math::floor
fvar< T > floor(const fvar< T > &x)
Definition: floor.hpp:11
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.